Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/pytest_vulture/__init__.py | 7 | 7 | 6 | 0.00%
src/pytest_vulture/conf/base.py | 23 | 23 | 0 | 0.00%
src/pytest_vulture/conf/package.py | 33 | 33 | 4 | 0.00%
src/pytest_vulture/conf/reader.py | 33 | 33 | 4 | 0.00%
src/pytest_vulture/conf/vulture.py | 54 | 54 | 2 | 0.00%
src/pytest_vulture/setup_manager.py | 111 | 111 | 4 | 0.00%
src/pytest_vulture/vulture/comment.py | 53 | 53 | 11 | 0.00%
src/pytest_vulture/vulture/manager.py | 49 | 49 | 0 | 0.00%
Total | 363 | 363 | 31 | 0.00%

No items found using the specified filter.

2 files skipped due to complete coverage.